from setuptools import setup

setup(
    name='genetic_ai',
    version='0.1.6',
    packages=['genetic_ai'],
    url='',
    license='',
    author='AI University',
    author_email='nejronki@gmail.com'    
)